qec\_lego\_bench package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   qec_lego_bench.cli
   qec_lego_bench.codes
   qec_lego_bench.decoders
   qec_lego_bench.noises

Submodules
----------

qec\_lego\_bench.skeleton module
--------------------------------

.. automodule:: qec_lego_bench.skeleton
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: qec_lego_bench
   :members:
   :undoc-members:
   :show-inheritance:
